# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cognito.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_cognito.proto\x12\x17oak9.tython.aws.cognito\x1a\x13shared/shared.proto\"{\n\x14IdentityPoolPushSync\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_arns\x18\x02 \x03(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xa9\x01\n#IdentityPoolCognitoIdentityProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17server_side_token_check\x18\x02 \x01(\x08\x12\x15\n\rprovider_name\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\"\x96\x01\n\x1aIdentityPoolCognitoStreams\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10streaming_status\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\xae\x06\n\x0cIdentityPool\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\tpush_sync\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.cognito.IdentityPoolPushSync\x12`\n\x1a\x63ognito_identity_providers\x18\x03 \x03(\x0b\x32<.oak9.tython.aws.cognito.IdentityPoolCognitoIdentityProvider\x12P\n\x0e\x63ognito_events\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.cognito.IdentityPool.CognitoEventsEntry\x12\x1f\n\x17\x64\x65veloper_provider_name\x18\x05 \x01(\t\x12L\n\x0f\x63ognito_streams\x18\x06 \x01(\x0b\x32\x33.oak9.tython.aws.cognito.IdentityPoolCognitoStreams\x12\x1a\n\x12identity_pool_name\x18\x07 \x01(\t\x12(\n allow_unauthenticated_identities\x18\x08 \x01(\x08\x12\x65\n\x19supported_login_providers\x18\t \x03(\x0b\x32\x42.oak9.tython.aws.cognito.IdentityPool.SupportedLoginProvidersEntry\x12\x1a\n\x12saml_provider_arns\x18\n \x03(\t\x12%\n\x1dopen_id_connect_provider_arns\x18\x0b \x03(\t\x12\x1a\n\x12\x61llow_classic_flow\x18\x0c \x01(\x08\x1a\x34\n\x12\x43ognitoEventsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a>\n\x1cSupportedLoginProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\t\n\x07\x43ognito\x12<\n\ridentity_pool\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.cognito.IdentityPool\x12Z\n\x1didentity_pool_role_attachment\x18\x02 \x03(\x0b\x32\x33.oak9.tython.aws.cognito.IdentityPoolRoleAttachment\x12\x34\n\tuser_pool\x18\x03 \x03(\x0b\x32!.oak9.tython.aws.cognito.UserPool\x12\x41\n\x10user_pool_client\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.cognito.UserPoolClient\x12\x41\n\x10user_pool_domain\x18\x05 \x03(\x0b\x32\'.oak9.tython.aws.cognito.UserPoolDomain\x12?\n\x0fuser_pool_group\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.cognito.UserPoolGroup\x12V\n\x1buser_pool_identity_provider\x18\x07 \x03(\x0b\x32\x31.oak9.tython.aws.cognito.UserPoolIdentityProvider\x12R\n\x19user_pool_resource_server\x18\x08 \x03(\x0b\x32/.oak9.tython.aws.cognito.UserPoolResourceServer\x12m\n\'user_pool_risk_configuration_attachment\x18\t \x03(\x0b\x32<.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachment\x12j\n&user_pool_u_i_customization_attachment\x18\n \x03(\x0b\x32:.oak9.tython.aws.cognito.UserPoolUICustomizationAttachment\x12=\n\x0euser_pool_user\x18\x0b \x03(\x0b\x32%.oak9.tython.aws.cognito.UserPoolUser\x12\x62\n\"user_pool_user_to_group_attachment\x18\x0c \x03(\x0b\x32\x36.oak9.tython.aws.cognito.UserPoolUserToGroupAttachment\x12r\n*identity_pool_role_attachment_mapping_rule\x18\r \x03(\x0b\x32>.oak9.tython.aws.cognito.IdentityPoolRoleAttachmentMappingRule\x12r\n*identity_pool_role_attachment_role_mapping\x18\x0e \x03(\x0b\x32>.oak9.tython.aws.cognito.IdentityPoolRoleAttachmentRoleMapping\"\xff\x02\n\x1aIdentityPoolRoleAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\rrole_mappings\x18\x02 \x03(\x0b\x32\x45.oak9.tython.aws.cognito.IdentityPoolRoleAttachment.RoleMappingsEntry\x12\x18\n\x10identity_pool_id\x18\x03 \x01(\t\x12M\n\x05roles\x18\x04 \x03(\x0b\x32>.oak9.tython.aws.cognito.IdentityPoolRoleAttachment.RolesEntry\x1a\x33\n\x11RoleMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nRolesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x01\n\x16UserPoolPasswordPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frequire_numbers\x18\x02 \x01(\x08\x12\x16\n\x0eminimum_length\x18\x03 \x01(\x05\x12(\n temporary_password_validity_days\x18\x04 \x01(\x05\x12\x19\n\x11require_uppercase\x18\x05 \x01(\x08\x12\x19\n\x11require_lowercase\x18\x06 \x01(\x08\x12\x17\n\x0frequire_symbols\x18\x07 \x01(\x08\"\x95\x01\n\x10UserPoolPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x0fpassword_policy\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.cognito.UserPoolPasswordPolicy\"\xfd\x01\n#UserPoolVerificationMessageTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x65mail_message_by_link\x18\x02 \x01(\t\x12\x15\n\remail_message\x18\x03 \x01(\t\x12\x13\n\x0bsms_message\x18\x04 \x01(\t\x12\x15\n\remail_subject\x18\x05 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_email_option\x18\x06 \x01(\t\x12\x1d\n\x15\x65mail_subject_by_link\x18\x07 \x01(\t\"\x85\x01\n\"UserPoolStringAttributeConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nmin_length\x18\x02 \x01(\t\x12\x12\n\nmax_length\x18\x03 \x01(\t\"\x83\x01\n\"UserPoolNumberAttributeConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmin_value\x18\x02 \x01(\t\x12\x11\n\tmax_value\x18\x03 \x01(\t\"\x88\x03\n\x17UserPoolSchemaAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18\x64\x65veloper_only_attribute\x18\x02 \x01(\x08\x12\x0f\n\x07mutable\x18\x03 \x01(\x08\x12\x1b\n\x13\x61ttribute_data_type\x18\x04 \x01(\t\x12\x61\n\x1cstring_attribute_constraints\x18\x05 \x01(\x0b\x32;.oak9.tython.aws.cognito.UserPoolStringAttributeConstraints\x12\x10\n\x08required\x18\x06 \x01(\x08\x12\x61\n\x1cnumber_attribute_constraints\x18\x07 \x01(\x0b\x32;.oak9.tython.aws.cognito.UserPoolNumberAttributeConstraints\x12\x0c\n\x04name\x18\x08 \x01(\t\"\x9b\x01\n\x1dUserPoolInviteMessageTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\remail_message\x18\x02 \x01(\t\x12\x13\n\x0bsms_message\x18\x03 \x01(\t\x12\x15\n\remail_subject\x18\x04 \x01(\t\"\xfd\x01\n\x1dUserPoolAdminCreateUserConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x17invite_message_template\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.cognito.UserPoolInviteMessageTemplate\x12$\n\x1cunused_account_validity_days\x18\x03 \x01(\x05\x12$\n\x1c\x61llow_admin_create_user_only\x18\x04 \x01(\x08\"p\n\x1dUserPoolUsernameConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63\x61se_sensitive\x18\x02 \x01(\x08\"q\n\x16UserPoolUserPoolAddOns\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x61\x64vanced_security_mode\x18\x02 \x01(\t\"\xd1\x01\n\x1aUserPoolEmailConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16reply_to_email_address\x18\x02 \x01(\t\x12\x19\n\x11\x63onfiguration_set\x18\x03 \x01(\t\x12\x1d\n\x15\x65mail_sending_account\x18\x04 \x01(\t\x12\x12\n\nsource_arn\x18\x05 \x01(\t\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\"\x80\x01\n\x18UserPoolSmsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65xternal_id\x18\x02 \x01(\t\x12\x16\n\x0esns_caller_arn\x18\x03 \x01(\t\"\xec\x02\n\x14UserPoolLambdaConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63reate_auth_challenge\x18\x02 \x01(\t\x12\x1a\n\x12pre_authentication\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65\x66ine_auth_challenge\x18\x04 \x01(\t\x12\x13\n\x0bpre_sign_up\x18\x05 \x01(\t\x12\x1c\n\x14pre_token_generation\x18\x06 \x01(\t\x12\x16\n\x0euser_migration\x18\x07 \x01(\t\x12\x1b\n\x13post_authentication\x18\x08 \x01(\t\x12\x19\n\x11post_confirmation\x18\t \x01(\t\x12\x16\n\x0e\x63ustom_message\x18\n \x01(\t\x12&\n\x1everify_auth_challenge_response\x18\x0b \x01(\t\"\xaf\x01\n\x1bUserPoolDeviceConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n%device_only_remembered_on_user_prompt\x18\x02 \x01(\x08\x12(\n challenge_required_on_new_device\x18\x03 \x01(\x08\"q\n\x16UserPoolRecoveryOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xa7\x01\n\x1eUserPoolAccountRecoverySetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x13recovery_mechanisms\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.cognito.UserPoolRecoveryOption\"\xec\n\n\x08UserPool\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x0euser_pool_tags\x18\x02 \x03(\x0b\x32\x33.oak9.tython.aws.cognito.UserPool.UserPoolTagsEntry\x12;\n\x08policies\x18\x03 \x01(\x0b\x32).oak9.tython.aws.cognito.UserPoolPolicies\x12\x63\n\x1dverification_message_template\x18\x04 \x01(\x0b\x32<.oak9.tython.aws.cognito.UserPoolVerificationMessageTemplate\x12\x19\n\x11mfa_configuration\x18\x05 \x01(\t\x12@\n\x06schema\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.cognito.UserPoolSchemaAttribute\x12X\n\x18\x61\x64min_create_user_config\x18\x07 \x01(\x0b\x32\x36.oak9.tython.aws.cognito.UserPoolAdminCreateUserConfig\x12\"\n\x1asms_authentication_message\x18\x08 \x01(\t\x12V\n\x16username_configuration\x18\t \x01(\x0b\x32\x36.oak9.tython.aws.cognito.UserPoolUsernameConfiguration\x12\x16\n\x0euser_pool_name\x18\n \x01(\t\x12 \n\x18sms_verification_message\x18\x0b \x01(\t\x12J\n\x11user_pool_add_ons\x18\x0c \x01(\x0b\x32/.oak9.tython.aws.cognito.UserPoolUserPoolAddOns\x12P\n\x13\x65mail_configuration\x18\r \x01(\x0b\x32\x33.oak9.tython.aws.cognito.UserPoolEmailConfiguration\x12L\n\x11sms_configuration\x18\x0e \x01(\x0b\x32\x31.oak9.tython.aws.cognito.UserPoolSmsConfiguration\x12\x18\n\x10\x61lias_attributes\x18\x0f \x03(\t\x12\x14\n\x0c\x65nabled_mfas\x18\x10 \x03(\t\x12\"\n\x1a\x65mail_verification_subject\x18\x11 \x01(\t\x12\x44\n\rlambda_config\x18\x12 \x01(\x0b\x32-.oak9.tython.aws.cognito.UserPoolLambdaConfig\x12\x1b\n\x13username_attributes\x18\x13 \x03(\t\x12 \n\x18\x61uto_verified_attributes\x18\x14 \x03(\t\x12R\n\x14\x64\x65vice_configuration\x18\x15 \x01(\x0b\x32\x34.oak9.tython.aws.cognito.UserPoolDeviceConfiguration\x12\"\n\x1a\x65mail_verification_message\x18\x16 \x01(\t\x12Y\n\x18\x61\x63\x63ount_recovery_setting\x18\x17 \x01(\x0b\x32\x37.oak9.tython.aws.cognito.UserPoolAccountRecoverySetting\x1a\x33\n\x11UserPoolTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x01\n$UserPoolClientAnalyticsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10user_data_shared\x18\x02 \x01(\x08\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\x9a\x01\n UserPoolClientTokenValidityUnits\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08id_token\x18\x02 \x01(\t\x12\x15\n\rrefresh_token\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\"\xf9\x05\n\x0eUserPoolClient\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12^\n\x17\x61nalytics_configuration\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.cognito.UserPoolClientAnalyticsConfiguration\x12\x17\n\x0fgenerate_secret\x18\x03 \x01(\x08\x12\x17\n\x0f\x63\x61llback_u_r_ls\x18\x04 \x03(\t\x12\x19\n\x11id_token_validity\x18\x05 \x01(\x05\x12\x1d\n\x15\x61llowed_o_auth_scopes\x18\x06 \x03(\t\x12W\n\x14token_validity_units\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.cognito.UserPoolClientTokenValidityUnits\x12\x17\n\x0fread_attributes\x18\x08 \x03(\t\x12-\n%allowed_o_auth_flows_user_pool_client\x18\t \x01(\x08\x12\x1e\n\x16\x64\x65\x66\x61ult_redirect_u_r_i\x18\n \x01(\t\x12$\n\x1csupported_identity_providers\x18\x0b \x03(\t\x12\x13\n\x0b\x63lient_name\x18\x0c \x01(\t\x12\x14\n\x0cuser_pool_id\x18\r \x01(\t\x12\x1c\n\x14\x61llowed_o_auth_flows\x18\x0e \x03(\t\x12\x1b\n\x13\x65xplicit_auth_flows\x18\x0f \x03(\t\x12\x15\n\rlogout_u_r_ls\x18\x10 \x03(\t\x12\x1d\n\x15\x61\x63\x63\x65ss_token_validity\x18\x11 \x01(\x05\x12\x1e\n\x16refresh_token_validity\x18\x12 \x01(\x05\x12\x18\n\x10write_attributes\x18\x13 \x03(\t\x12%\n\x1dprevent_user_existence_errors\x18\x14 \x01(\t\"x\n$UserPoolDomainCustomDomainConfigType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\"\xcc\x01\n\x0eUserPoolDomain\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cuser_pool_id\x18\x02 \x01(\t\x12[\n\x14\x63ustom_domain_config\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.cognito.UserPoolDomainCustomDomainConfigType\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\"\xad\x01\n\rUserPoolGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x04 \x01(\t\x12\x12\n\nprecedence\x18\x05 \x01(\x01\x12\x10\n\x08role_arn\x18\x06 \x01(\t\"\xe7\x03\n\x18UserPoolIdentityProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rprovider_name\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x62\n\x11\x61ttribute_mapping\x18\x04 \x03(\x0b\x32G.oak9.tython.aws.cognito.UserPoolIdentityProvider.AttributeMappingEntry\x12`\n\x10provider_details\x18\x05 \x03(\x0b\x32\x46.oak9.tython.aws.cognito.UserPoolIdentityProvider.ProviderDetailsEntry\x12\x15\n\rprovider_type\x18\x06 \x01(\t\x12\x17\n\x0fidp_identifiers\x18\x07 \x03(\t\x1a\x37\n\x15\x41ttributeMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ProviderDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n-UserPoolResourceServerResourceServerScopeType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nscope_name\x18\x02 \x01(\t\x12\x19\n\x11scope_description\x18\x03 \x01(\t\"\xe1\x01\n\x16UserPoolResourceServer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cuser_pool_id\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12V\n\x06scopes\x18\x04 \x03(\x0b\x32\x46.oak9.tython.aws.cognito.UserPoolResourceServerResourceServerScopeType\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x95\x01\nDUserPoolRiskConfigurationAttachmentCompromisedCredentialsActionsType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x65vent_action\x18\x02 \x01(\t\"\x8f\x02\nNUserPoolRiskConfigurationAttachmentCompromisedCredentialsRiskConfigurationType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12n\n\x07\x61\x63tions\x18\x02 \x01(\x0b\x32].oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentCompromisedCredentialsActionsType\x12\x14\n\x0c\x65vent_filter\x18\x03 \x03(\t\"\x9d\x01\n<UserPoolRiskConfigurationAttachmentAccountTakeoverActionType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06notify\x18\x02 \x01(\x08\x12\x14\n\x0c\x65vent_action\x18\x03 \x01(\t\"\xbd\x03\n=UserPoolRiskConfigurationAttachmentAccountTakeoverActionsType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12j\n\x0bhigh_action\x18\x02 \x01(\x0b\x32U.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionType\x12i\n\nlow_action\x18\x03 \x01(\x0b\x32U.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionType\x12l\n\rmedium_action\x18\x04 \x01(\x0b\x32U.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionType\"\xa4\x01\n2UserPoolRiskConfigurationAttachmentNotifyEmailType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ttext_body\x18\x02 \x01(\t\x12\x11\n\thtml_body\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\"\xd1\x03\n:UserPoolRiskConfigurationAttachmentNotifyConfigurationType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x0b\x62lock_email\x18\x02 \x01(\x0b\x32K.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentNotifyEmailType\x12\x10\n\x08reply_to\x18\x03 \x01(\t\x12\x12\n\nsource_arn\x18\x04 \x01(\t\x12\x64\n\x0fno_action_email\x18\x05 \x01(\x0b\x32K.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentNotifyEmailType\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\x12^\n\tmfa_email\x18\x07 \x01(\x0b\x32K.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentNotifyEmailType\"\xde\x02\nGUserPoolRiskConfigurationAttachmentAccountTakeoverRiskConfigurationType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x07\x61\x63tions\x18\x02 \x01(\x0b\x32V.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionsType\x12q\n\x14notify_configuration\x18\x03 \x01(\x0b\x32S.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentNotifyConfigurationType\"\xba\x01\nAUserPoolRiskConfigurationAttachmentRiskExceptionConfigurationType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x62locked_ip_range_list\x18\x02 \x03(\t\x12\x1d\n\x15skipped_ip_range_list\x18\x03 \x03(\t\"\xb8\x04\n#UserPoolRiskConfigurationAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x9b\x01\n*compromised_credentials_risk_configuration\x18\x02 \x01(\x0b\x32g.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentCompromisedCredentialsRiskConfigurationType\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x8d\x01\n#account_takeover_risk_configuration\x18\x05 \x01(\x0b\x32`.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverRiskConfigurationType\x12\x80\x01\n\x1crisk_exception_configuration\x18\x06 \x01(\x0b\x32Z.oak9.tython.aws.cognito.UserPoolRiskConfigurationAttachmentRiskExceptionConfigurationType\"\x93\x01\n!UserPoolUICustomizationAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x63s_s\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\"q\n\x19UserPoolUserAttributeType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xec\x03\n\x0cUserPoolUser\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x0fvalidation_data\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.cognito.UserPoolUserAttributeType\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x16\n\x0emessage_action\x18\x05 \x01(\t\x12R\n\x0f\x63lient_metadata\x18\x06 \x03(\x0b\x32\x39.oak9.tython.aws.cognito.UserPoolUser.ClientMetadataEntry\x12 \n\x18\x64\x65sired_delivery_mediums\x18\x07 \x03(\t\x12\x1c\n\x14\x66orce_alias_creation\x18\x08 \x01(\x08\x12K\n\x0fuser_attributes\x18\t \x03(\x0b\x32\x32.oak9.tython.aws.cognito.UserPoolUserAttributeType\x1a\x35\n\x13\x43lientMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x01\n\x1dUserPoolUserToGroupAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\xa4\x01\n%IdentityPoolRoleAttachmentMappingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nmatch_type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\r\n\x05\x63laim\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xba\x01\n0IdentityPoolRoleAttachmentRulesConfigurationType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x05rules\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.cognito.IdentityPoolRoleAttachmentMappingRule\"\x86\x02\n%IdentityPoolRoleAttachmentRoleMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x61mbiguous_role_resolution\x18\x02 \x01(\t\x12\x66\n\x13rules_configuration\x18\x03 \x01(\x0b\x32I.oak9.tython.aws.cognito.IdentityPoolRoleAttachmentRulesConfigurationType\x12\x19\n\x11identity_provider\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cognito_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTITYPOOL_COGNITOEVENTSENTRY._options = None
  _IDENTITYPOOL_COGNITOEVENTSENTRY._serialized_options = b'8\001'
  _IDENTITYPOOL_SUPPORTEDLOGINPROVIDERSENTRY._options = None
  _IDENTITYPOOL_SUPPORTEDLOGINPROVIDERSENTRY._serialized_options = b'8\001'
  _IDENTITYPOOLROLEATTACHMENT_ROLEMAPPINGSENTRY._options = None
  _IDENTITYPOOLROLEATTACHMENT_ROLEMAPPINGSENTRY._serialized_options = b'8\001'
  _IDENTITYPOOLROLEATTACHMENT_ROLESENTRY._options = None
  _IDENTITYPOOLROLEATTACHMENT_ROLESENTRY._serialized_options = b'8\001'
  _USERPOOL_USERPOOLTAGSENTRY._options = None
  _USERPOOL_USERPOOLTAGSENTRY._serialized_options = b'8\001'
  _USERPOOLIDENTITYPROVIDER_ATTRIBUTEMAPPINGENTRY._options = None
  _USERPOOLIDENTITYPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_options = b'8\001'
  _USERPOOLIDENTITYPROVIDER_PROVIDERDETAILSENTRY._options = None
  _USERPOOLIDENTITYPROVIDER_PROVIDERDETAILSENTRY._serialized_options = b'8\001'
  _USERPOOLUSER_CLIENTMETADATAENTRY._options = None
  _USERPOOLUSER_CLIENTMETADATAENTRY._serialized_options = b'8\001'
  _IDENTITYPOOLPUSHSYNC._serialized_start=71
  _IDENTITYPOOLPUSHSYNC._serialized_end=194
  _IDENTITYPOOLCOGNITOIDENTITYPROVIDER._serialized_start=197
  _IDENTITYPOOLCOGNITOIDENTITYPROVIDER._serialized_end=366
  _IDENTITYPOOLCOGNITOSTREAMS._serialized_start=369
  _IDENTITYPOOLCOGNITOSTREAMS._serialized_end=519
  _IDENTITYPOOL._serialized_start=522
  _IDENTITYPOOL._serialized_end=1336
  _IDENTITYPOOL_COGNITOEVENTSENTRY._serialized_start=1220
  _IDENTITYPOOL_COGNITOEVENTSENTRY._serialized_end=1272
  _IDENTITYPOOL_SUPPORTEDLOGINPROVIDERSENTRY._serialized_start=1274
  _IDENTITYPOOL_SUPPORTEDLOGINPROVIDERSENTRY._serialized_end=1336
  _COGNITO._serialized_start=1339
  _COGNITO._serialized_end=2541
  _IDENTITYPOOLROLEATTACHMENT._serialized_start=2544
  _IDENTITYPOOLROLEATTACHMENT._serialized_end=2927
  _IDENTITYPOOLROLEATTACHMENT_ROLEMAPPINGSENTRY._serialized_start=2830
  _IDENTITYPOOLROLEATTACHMENT_ROLEMAPPINGSENTRY._serialized_end=2881
  _IDENTITYPOOLROLEATTACHMENT_ROLESENTRY._serialized_start=2883
  _IDENTITYPOOLROLEATTACHMENT_ROLESENTRY._serialized_end=2927
  _USERPOOLPASSWORDPOLICY._serialized_start=2930
  _USERPOOLPASSWORDPOLICY._serialized_end=3181
  _USERPOOLPOLICIES._serialized_start=3184
  _USERPOOLPOLICIES._serialized_end=3333
  _USERPOOLVERIFICATIONMESSAGETEMPLATE._serialized_start=3336
  _USERPOOLVERIFICATIONMESSAGETEMPLATE._serialized_end=3589
  _USERPOOLSTRINGATTRIBUTECONSTRAINTS._serialized_start=3592
  _USERPOOLSTRINGATTRIBUTECONSTRAINTS._serialized_end=3725
  _USERPOOLNUMBERATTRIBUTECONSTRAINTS._serialized_start=3728
  _USERPOOLNUMBERATTRIBUTECONSTRAINTS._serialized_end=3859
  _USERPOOLSCHEMAATTRIBUTE._serialized_start=3862
  _USERPOOLSCHEMAATTRIBUTE._serialized_end=4254
  _USERPOOLINVITEMESSAGETEMPLATE._serialized_start=4257
  _USERPOOLINVITEMESSAGETEMPLATE._serialized_end=4412
  _USERPOOLADMINCREATEUSERCONFIG._serialized_start=4415
  _USERPOOLADMINCREATEUSERCONFIG._serialized_end=4668
  _USERPOOLUSERNAMECONFIGURATION._serialized_start=4670
  _USERPOOLUSERNAMECONFIGURATION._serialized_end=4782
  _USERPOOLUSERPOOLADDONS._serialized_start=4784
  _USERPOOLUSERPOOLADDONS._serialized_end=4897
  _USERPOOLEMAILCONFIGURATION._serialized_start=4900
  _USERPOOLEMAILCONFIGURATION._serialized_end=5109
  _USERPOOLSMSCONFIGURATION._serialized_start=5112
  _USERPOOLSMSCONFIGURATION._serialized_end=5240
  _USERPOOLLAMBDACONFIG._serialized_start=5243
  _USERPOOLLAMBDACONFIG._serialized_end=5607
  _USERPOOLDEVICECONFIGURATION._serialized_start=5610
  _USERPOOLDEVICECONFIGURATION._serialized_end=5785
  _USERPOOLRECOVERYOPTION._serialized_start=5787
  _USERPOOLRECOVERYOPTION._serialized_end=5900
  _USERPOOLACCOUNTRECOVERYSETTING._serialized_start=5903
  _USERPOOLACCOUNTRECOVERYSETTING._serialized_end=6070
  _USERPOOL._serialized_start=6073
  _USERPOOL._serialized_end=7461
  _USERPOOL_USERPOOLTAGSENTRY._serialized_start=7410
  _USERPOOL_USERPOOLTAGSENTRY._serialized_end=7461
  _USERPOOLCLIENTANALYTICSCONFIGURATION._serialized_start=7464
  _USERPOOLCLIENTANALYTICSCONFIGURATION._serialized_end=7648
  _USERPOOLCLIENTTOKENVALIDITYUNITS._serialized_start=7651
  _USERPOOLCLIENTTOKENVALIDITYUNITS._serialized_end=7805
  _USERPOOLCLIENT._serialized_start=7808
  _USERPOOLCLIENT._serialized_end=8569
  _USERPOOLDOMAINCUSTOMDOMAINCONFIGTYPE._serialized_start=8571
  _USERPOOLDOMAINCUSTOMDOMAINCONFIGTYPE._serialized_end=8691
  _USERPOOLDOMAIN._serialized_start=8694
  _USERPOOLDOMAIN._serialized_end=8898
  _USERPOOLGROUP._serialized_start=8901
  _USERPOOLGROUP._serialized_end=9074
  _USERPOOLIDENTITYPROVIDER._serialized_start=9077
  _USERPOOLIDENTITYPROVIDER._serialized_end=9564
  _USERPOOLIDENTITYPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_start=9453
  _USERPOOLIDENTITYPROVIDER_ATTRIBUTEMAPPINGENTRY._serialized_end=9508
  _USERPOOLIDENTITYPROVIDER_PROVIDERDETAILSENTRY._serialized_start=9510
  _USERPOOLIDENTITYPROVIDER_PROVIDERDETAILSENTRY._serialized_end=9564
  _USERPOOLRESOURCESERVERRESOURCESERVERSCOPETYPE._serialized_start=9567
  _USERPOOLRESOURCESERVERRESOURCESERVERSCOPETYPE._serialized_end=9718
  _USERPOOLRESOURCESERVER._serialized_start=9721
  _USERPOOLRESOURCESERVER._serialized_end=9946
  _USERPOOLRISKCONFIGURATIONATTACHMENTCOMPROMISEDCREDENTIALSACTIONSTYPE._serialized_start=9949
  _USERPOOLRISKCONFIGURATIONATTACHMENTCOMPROMISEDCREDENTIALSACTIONSTYPE._serialized_end=10098
  _USERPOOLRISKCONFIGURATIONATTACHMENTCOMPROMISEDCREDENTIALSRISKCONFIGURATIONTYPE._serialized_start=10101
  _USERPOOLRISKCONFIGURATIONATTACHMENTCOMPROMISEDCREDENTIALSRISKCONFIGURATIONTYPE._serialized_end=10372
  _USERPOOLRISKCONFIGURATIONATTACHMENTACCOUNTTAKEOVERACTIONTYPE._serialized_start=10375
  _USERPOOLRISKCONFIGURATIONATTACHMENTACCOUNTTAKEOVERACTIONTYPE._serialized_end=10532
  _USERPOOLRISKCONFIGURATIONATTACHMENTACCOUNTTAKEOVERACTIONSTYPE._serialized_start=10535
  _USERPOOLRISKCONFIGURATIONATTACHMENTACCOUNTTAKEOVERACTIONSTYPE._serialized_end=10980
  _USERPOOLRISKCONFIGURATIONATTACHMENTNOTIFYEMAILTYPE._serialized_start=10983
  _USERPOOLRISKCONFIGURATIONATTACHMENTNOTIFYEMAILTYPE._serialized_end=11147
  _USERPOOLRISKCONFIGURATIONATTACHMENTNOTIFYCONFIGURATIONTYPE._serialized_start=11150
  _USERPOOLRISKCONFIGURATIONATTACHMENTNOTIFYCONFIGURATIONTYPE._serialized_end=11615
  _USERPOOLRISKCONFIGURATIONATTACHMENTACCOUNTTAKEOVERRISKCONFIGURATIONTYPE._serialized_start=11618
  _USERPOOLRISKCONFIGURATIONATTACHMENTACCOUNTTAKEOVERRISKCONFIGURATIONTYPE._serialized_end=11968
  _USERPOOLRISKCONFIGURATIONATTACHMENTRISKEXCEPTIONCONFIGURATIONTYPE._serialized_start=11971
  _USERPOOLRISKCONFIGURATIONATTACHMENTRISKEXCEPTIONCONFIGURATIONTYPE._serialized_end=12157
  _USERPOOLRISKCONFIGURATIONATTACHMENT._serialized_start=12160
  _USERPOOLRISKCONFIGURATIONATTACHMENT._serialized_end=12728
  _USERPOOLUICUSTOMIZATIONATTACHMENT._serialized_start=12731
  _USERPOOLUICUSTOMIZATIONATTACHMENT._serialized_end=12878
  _USERPOOLUSERATTRIBUTETYPE._serialized_start=12880
  _USERPOOLUSERATTRIBUTETYPE._serialized_end=12993
  _USERPOOLUSER._serialized_start=12996
  _USERPOOLUSER._serialized_end=13488
  _USERPOOLUSER_CLIENTMETADATAENTRY._serialized_start=13435
  _USERPOOLUSER_CLIENTMETADATAENTRY._serialized_end=13488
  _USERPOOLUSERTOGROUPATTACHMENT._serialized_start=13491
  _USERPOOLUSERTOGROUPATTACHMENT._serialized_end=13639
  _IDENTITYPOOLROLEATTACHMENTMAPPINGRULE._serialized_start=13642
  _IDENTITYPOOLROLEATTACHMENTMAPPINGRULE._serialized_end=13806
  _IDENTITYPOOLROLEATTACHMENTRULESCONFIGURATIONTYPE._serialized_start=13809
  _IDENTITYPOOLROLEATTACHMENTRULESCONFIGURATIONTYPE._serialized_end=13995
  _IDENTITYPOOLROLEATTACHMENTROLEMAPPING._serialized_start=13998
  _IDENTITYPOOLROLEATTACHMENTROLEMAPPING._serialized_end=14260
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_amplify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_amplify.proto\x12\x17oak9.tython.aws.amplify\x1a\x13shared/shared.proto\"n\n\x16\x41ppEnvironmentVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8c\x01\n\x12\x41ppBasicAuthConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x19\n\x11\x65nable_basic_auth\x18\x03 \x01(\x08\x12\x10\n\x08password\x18\x04 \x01(\t\"\xe5\x03\n\x1b\x41ppAutoBranchCreationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x15\x65nvironment_variables\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.amplify.AppEnvironmentVariable\x12#\n\x1b\x65nable_auto_branch_creation\x18\x03 \x01(\x08\x12%\n\x1dpull_request_environment_name\x18\x04 \x01(\t\x12%\n\x1d\x61uto_branch_creation_patterns\x18\x05 \x03(\t\x12#\n\x1b\x65nable_pull_request_preview\x18\x06 \x01(\x08\x12\x19\n\x11\x65nable_auto_build\x18\x07 \x01(\x08\x12\x1f\n\x17\x65nable_performance_mode\x18\x08 \x01(\x08\x12\x12\n\nbuild_spec\x18\t \x01(\t\x12\r\n\x05stage\x18\n \x01(\t\x12\x46\n\x11\x62\x61sic_auth_config\x18\x0b \x01(\x0b\x32+.oak9.tython.aws.amplify.AppBasicAuthConfig\"\x8b\x01\n\rAppCustomRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcondition\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\"\x87\x05\n\x03\x41pp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x1b\x61uto_branch_creation_config\x18\x02 \x01(\x0b\x32\x34.oak9.tython.aws.amplify.AppAutoBranchCreationConfig\x12\x13\n\x0boauth_token\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12#\n\x1b\x65nable_branch_auto_deletion\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x12\n\nrepository\x18\x07 \x01(\t\x12N\n\x15\x65nvironment_variables\x18\x08 \x03(\x0b\x32/.oak9.tython.aws.amplify.AppEnvironmentVariable\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\t \x01(\t\x12\x12\n\nbuild_spec\x18\n \x01(\t\x12<\n\x0c\x63ustom_rules\x18\x0b \x03(\x0b\x32&.oak9.tython.aws.amplify.AppCustomRule\x12\x46\n\x11\x62\x61sic_auth_config\x18\x0c \x01(\x0b\x32+.oak9.tython.aws.amplify.AppBasicAuthConfig\x12\x34\n\x04tags\x18\r \x03(\x0b\x32&.oak9.tython.aws.amplify.App.TagsEntry\x12\x18\n\x10iam_service_role\x18\x0e \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\x07\x41mplify\x12)\n\x03\x61pp\x18\x01 \x03(\x0b\x32\x1c.oak9.tython.aws.amplify.App\x12/\n\x06\x62ranch\x18\x02 \x03(\x0b\x32\x1f.oak9.tython.aws.amplify.Branch\x12/\n\x06\x64omain\x18\x03 \x03(\x0b\x32\x1f.oak9.tython.aws.amplify.Domain\"q\n\x19\x42ranchEnvironmentVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8f\x01\n\x15\x42ranchBasicAuthConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x19\n\x11\x65nable_basic_auth\x18\x03 \x01(\x08\x12\x10\n\x08password\x18\x04 \x01(\t\"\xaa\x04\n\x06\x42ranch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12Q\n\x15\x65nvironment_variables\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.amplify.BranchEnvironmentVariable\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12%\n\x1dpull_request_environment_name\x18\x05 \x01(\t\x12#\n\x1b\x65nable_pull_request_preview\x18\x06 \x01(\x08\x12\x19\n\x11\x65nable_auto_build\x18\x07 \x01(\x08\x12\x1f\n\x17\x65nable_performance_mode\x18\x08 \x01(\x08\x12\x12\n\nbuild_spec\x18\t \x01(\t\x12\r\n\x05stage\x18\n \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x0b \x01(\t\x12I\n\x11\x62\x61sic_auth_config\x18\x0c \x01(\x0b\x32..oak9.tython.aws.amplify.BranchBasicAuthConfig\x12\x37\n\x04tags\x18\r \x03(\x0b\x32).oak9.tython.aws.amplify.Branch.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\x16\x44omainSubDomainSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x03 \x01(\t\"\xa1\x02\n\x06\x44omain\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x13sub_domain_settings\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.amplify.DomainSubDomainSetting\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12 \n\x18\x61uto_sub_domain_iam_role\x18\x04 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x05 \x01(\t\x12\x1e\n\x16\x65nable_auto_sub_domain\x18\x06 \x01(\x08\x12)\n!auto_sub_domain_creation_patterns\x18\x07 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_amplify_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APP_TAGSENTRY._options = None
  _APP_TAGSENTRY._serialized_options = b'8\001'
  _BRANCH_TAGSENTRY._options = None
  _BRANCH_TAGSENTRY._serialized_options = b'8\001'
  _APPENVIRONMENTVARIABLE._serialized_start=71
  _APPENVIRONMENTVARIABLE._serialized_end=181
  _APPBASICAUTHCONFIG._serialized_start=184
  _APPBASICAUTHCONFIG._serialized_end=324
  _APPAUTOBRANCHCREATIONCONFIG._serialized_start=327
  _APPAUTOBRANCHCREATIONCONFIG._serialized_end=812
  _APPCUSTOMRULE._serialized_start=815
  _APPCUSTOMRULE._serialized_end=954
  _APP._serialized_start=957
  _APP._serialized_end=1604
  _APP_TAGSENTRY._serialized_start=1561
  _APP_TAGSENTRY._serialized_end=1604
  _AMPLIFY._serialized_start=1607
  _AMPLIFY._serialized_end=1757
  _BRANCHENVIRONMENTVARIABLE._serialized_start=1759
  _BRANCHENVIRONMENTVARIABLE._serialized_end=1872
  _BRANCHBASICAUTHCONFIG._serialized_start=1875
  _BRANCHBASICAUTHCONFIG._serialized_end=2018
  _BRANCH._serialized_start=2021
  _BRANCH._serialized_end=2575
  _BRANCH_TAGSENTRY._serialized_start=1561
  _BRANCH_TAGSENTRY._serialized_end=1604
  _DOMAINSUBDOMAINSETTING._serialized_start=2577
  _DOMAINSUBDOMAINSETTING._serialized_end=2695
  _DOMAIN._serialized_start=2698
  _DOMAIN._serialized_end=2987
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NotificationChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SNS_ROLE_NAME_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    sns_role_name: builtins.str
    sns_topic_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        sns_role_name: builtins.str = ...,
        sns_topic_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sns_role_name", b"sns_role_name", "sns_topic_arn", b"sns_topic_arn"]) -> None: ...

global___NotificationChannel = NotificationChannel

@typing_extensions.final
class FMS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    @property
    def notification_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotificationChannel]: ...
    @property
    def policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Policy]: ...
    def __init__(
        self,
        *,
        notification_channel: collections.abc.Iterable[global___NotificationChannel] | None = ...,
        policy: collections.abc.Iterable[global___Policy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channel", b"notification_channel", "policy", b"policy"]) -> None: ...

global___FMS = FMS

@typing_extensions.final
class PolicyIEMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_FIELD_NUMBER: builtins.int
    ORGUNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def account(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def orgunit(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        account: collections.abc.Iterable[builtins.str] | None = ...,
        orgunit: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account", b"account", "orgunit", b"orgunit", "resource_info", b"resource_info"]) -> None: ...

global___PolicyIEMap = PolicyIEMap

@typing_extensions.final
class PolicyResourceTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___PolicyResourceTag = PolicyResourceTag

@typing_extensions.final
class PolicyPolicyTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___PolicyPolicyTag = PolicyPolicyTag

@typing_extensions.final
class Policy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecurityServicePolicyDataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXCLUDE_MAP_FIELD_NUMBER: builtins.int
    EXCLUDE_RESOURCE_TAGS_FIELD_NUMBER: builtins.int
    INCLUDE_MAP_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    REMEDIATION_ENABLED_FIELD_NUMBER: builtins.int
    RESOURCE_TAGS_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_LIST_FIELD_NUMBER: builtins.int
    SECURITY_SERVICE_POLICY_DATA_FIELD_NUMBER: builtins.int
    DELETE_ALL_POLICY_RESOURCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def exclude_map(self) -> global___PolicyIEMap: ...
    exclude_resource_tags: builtins.bool
    @property
    def include_map(self) -> global___PolicyIEMap: ...
    policy_name: builtins.str
    remediation_enabled: builtins.bool
    @property
    def resource_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicyResourceTag]: ...
    resource_type: builtins.str
    @property
    def resource_type_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_service_policy_data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    delete_all_policy_resources: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicyPolicyTag]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        exclude_map: global___PolicyIEMap | None = ...,
        exclude_resource_tags: builtins.bool = ...,
        include_map: global___PolicyIEMap | None = ...,
        policy_name: builtins.str = ...,
        remediation_enabled: builtins.bool = ...,
        resource_tags: collections.abc.Iterable[global___PolicyResourceTag] | None = ...,
        resource_type: builtins.str = ...,
        resource_type_list: collections.abc.Iterable[builtins.str] | None = ...,
        security_service_policy_data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        delete_all_policy_resources: builtins.bool = ...,
        tags: collections.abc.Iterable[global___PolicyPolicyTag] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exclude_map", b"exclude_map", "include_map", b"include_map", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_all_policy_resources", b"delete_all_policy_resources", "exclude_map", b"exclude_map", "exclude_resource_tags", b"exclude_resource_tags", "include_map", b"include_map", "policy_name", b"policy_name", "remediation_enabled", b"remediation_enabled", "resource_info", b"resource_info", "resource_tags", b"resource_tags", "resource_type", b"resource_type", "resource_type_list", b"resource_type_list", "security_service_policy_data", b"security_service_policy_data", "tags", b"tags"]) -> None: ...

global___Policy = Policy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_endpoints.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_endpoints.proto\x12\x19oak9.tython.gcp.endpoints\x1a\x13shared/shared.proto\"K\n\x19\x45ndpointsServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xac\x04\n\x10\x45ndpointsService\x12\x43\n\x04\x61pis\x18\x01 \x03(\x0b\x32\x35.oak9.tython.gcp.endpoints.EndpointsService.ApisEntry\x12\x11\n\tconfig_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64ns_address\x18\x03 \x01(\t\x12M\n\tendpoints\x18\x04 \x03(\x0b\x32:.oak9.tython.gcp.endpoints.EndpointsService.EndpointsEntry\x12\x13\n\x0bgrpc_config\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x16\n\x0eopenapi_config\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x1c\n\x14protoc_output_base64\x18\t \x01(\t\x12\x14\n\x0cservice_name\x18\n \x01(\t\x12\x46\n\x08timeouts\x18\x0b \x01(\x0b\x32\x34.oak9.tython.gcp.endpoints.EndpointsServiceXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a+\n\tApisEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0e\x45ndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n-EndpointsServiceConsumersIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa4\x02\n#EndpointsServiceConsumersIamBinding\x12\x18\n\x10\x63onsumer_project\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x14\n\x0cservice_name\x18\x06 \x01(\t\x12[\n\tcondition\x18\x07 \x01(\x0b\x32H.oak9.tython.gcp.endpoints.EndpointsServiceConsumersIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"f\n,EndpointsServiceConsumersIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa1\x02\n\"EndpointsServiceConsumersIamMember\x12\x18\n\x10\x63onsumer_project\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x14\n\x0cservice_name\x18\x06 \x01(\t\x12Z\n\tcondition\x18\x07 \x01(\x0b\x32G.oak9.tython.gcp.endpoints.EndpointsServiceConsumersIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbc\x01\n\"EndpointsServiceConsumersIamPolicy\x12\x18\n\x10\x63onsumer_project\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x14\n\x0cservice_name\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$EndpointsServiceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf8\x01\n\x1a\x45ndpointsServiceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x14\n\x0cservice_name\x18\x05 \x01(\t\x12R\n\tcondition\x18\x06 \x01(\x0b\x32?.oak9.tython.gcp.endpoints.EndpointsServiceIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#EndpointsServiceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x19\x45ndpointsServiceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x14\n\x0cservice_name\x18\x05 \x01(\t\x12Q\n\tcondition\x18\x06 \x01(\x0b\x32>.oak9.tython.gcp.endpoints.EndpointsServiceIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x99\x01\n\x19\x45ndpointsServiceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_endpoints_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINTSSERVICE_APISENTRY._options = None
  _ENDPOINTSSERVICE_APISENTRY._serialized_options = b'8\001'
  _ENDPOINTSSERVICE_ENDPOINTSENTRY._options = None
  _ENDPOINTSSERVICE_ENDPOINTSENTRY._serialized_options = b'8\001'
  _ENDPOINTSSERVICEXTIMEOUTS._serialized_start=75
  _ENDPOINTSSERVICEXTIMEOUTS._serialized_end=150
  _ENDPOINTSSERVICE._serialized_start=153
  _ENDPOINTSSERVICE._serialized_end=709
  _ENDPOINTSSERVICE_APISENTRY._serialized_start=616
  _ENDPOINTSSERVICE_APISENTRY._serialized_end=659
  _ENDPOINTSSERVICE_ENDPOINTSENTRY._serialized_start=661
  _ENDPOINTSSERVICE_ENDPOINTSENTRY._serialized_end=709
  _ENDPOINTSSERVICECONSUMERSIAMBINDINGXCONDITION._serialized_start=711
  _ENDPOINTSSERVICECONSUMERSIAMBINDINGXCONDITION._serialized_end=814
  _ENDPOINTSSERVICECONSUMERSIAMBINDING._serialized_start=817
  _ENDPOINTSSERVICECONSUMERSIAMBINDING._serialized_end=1109
  _ENDPOINTSSERVICECONSUMERSIAMMEMBERXCONDITION._serialized_start=1111
  _ENDPOINTSSERVICECONSUMERSIAMMEMBERXCONDITION._serialized_end=1213
  _ENDPOINTSSERVICECONSUMERSIAMMEMBER._serialized_start=1216
  _ENDPOINTSSERVICECONSUMERSIAMMEMBER._serialized_end=1505
  _ENDPOINTSSERVICECONSUMERSIAMPOLICY._serialized_start=1508
  _ENDPOINTSSERVICECONSUMERSIAMPOLICY._serialized_end=1696
  _ENDPOINTSSERVICEIAMBINDINGXCONDITION._serialized_start=1698
  _ENDPOINTSSERVICEIAMBINDINGXCONDITION._serialized_end=1792
  _ENDPOINTSSERVICEIAMBINDING._serialized_start=1795
  _ENDPOINTSSERVICEIAMBINDING._serialized_end=2043
  _ENDPOINTSSERVICEIAMMEMBERXCONDITION._serialized_start=2045
  _ENDPOINTSSERVICEIAMMEMBERXCONDITION._serialized_end=2138
  _ENDPOINTSSERVICEIAMMEMBER._serialized_start=2141
  _ENDPOINTSSERVICEIAMMEMBER._serialized_end=2386
  _ENDPOINTSSERVICEIAMPOLICY._serialized_start=2389
  _ENDPOINTSSERVICEIAMPOLICY._serialized_end=2542
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_subnetwork.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n gcp/gcp_compute_subnetwork.proto\x12\"oak9.tython.gcp.compute_subnetwork\x1a\x13shared/shared.proto\"\x92\x01\n\x1b\x43omputeSubnetworkXLogConfig\x12\x1c\n\x14\x61ggregation_interval\x18\x01 \x01(\t\x12\x13\n\x0b\x66ilter_expr\x18\x02 \x01(\t\x12\x15\n\rflow_sampling\x18\x03 \x01(\x01\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\x17\n\x0fmetadata_fields\x18\x05 \x03(\t\"L\n\x1a\x43omputeSubnetworkXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb4\x06\n\x11\x43omputeSubnetwork\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1c\n\x14\x65xternal_ipv6_prefix\x18\x03 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x04 \x01(\t\x12\x17\n\x0fgateway_address\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x15\n\rip_cidr_range\x18\x07 \x01(\t\x12\x18\n\x10ipv6_access_type\x18\x08 \x01(\t\x12\x17\n\x0fipv6_cidr_range\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07network\x18\x0b \x01(\t\x12 \n\x18private_ip_google_access\x18\x0c \x01(\x08\x12\"\n\x1aprivate_ipv6_google_access\x18\r \x01(\t\x12\x0f\n\x07project\x18\x0e \x01(\t\x12\x0f\n\x07purpose\x18\x0f \x01(\t\x12\x0e\n\x06region\x18\x10 \x01(\t\x12\x0c\n\x04role\x18\x11 \x01(\t\x12g\n\x12secondary_ip_range\x18\x12 \x03(\x0b\x32K.oak9.tython.gcp.compute_subnetwork.ComputeSubnetwork.SecondaryIpRangeEntry\x12\x11\n\tself_link\x18\x13 \x01(\t\x12\x12\n\nstack_type\x18\x14 \x01(\t\x12S\n\nlog_config\x18\x15 \x01(\x0b\x32?.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkXLogConfig\x12P\n\x08timeouts\x18\x16 \x01(\x0b\x32>.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkXTimeouts\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15SecondaryIpRangeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"_\n%ComputeSubnetworkIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa2\x02\n\x1b\x43omputeSubnetworkIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x12\n\nsubnetwork\x18\x07 \x01(\t\x12\\\n\tcondition\x18\x08 \x01(\x0b\x32I.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$ComputeSubnetworkIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9f\x02\n\x1a\x43omputeSubnetworkIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x12\n\nsubnetwork\x18\x07 \x01(\t\x12[\n\tcondition\x18\x08 \x01(\x0b\x32H.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x01\n\x1a\x43omputeSubnetworkIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x12\n\nsubnetwork\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_subnetwork_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESUBNETWORK_SECONDARYIPRANGEENTRY._options = None
  _COMPUTESUBNETWORK_SECONDARYIPRANGEENTRY._serialized_options = b'8\001'
  _COMPUTESUBNETWORKXLOGCONFIG._serialized_start=94
  _COMPUTESUBNETWORKXLOGCONFIG._serialized_end=240
  _COMPUTESUBNETWORKXTIMEOUTS._serialized_start=242
  _COMPUTESUBNETWORKXTIMEOUTS._serialized_end=318
  _COMPUTESUBNETWORK._serialized_start=321
  _COMPUTESUBNETWORK._serialized_end=1141
  _COMPUTESUBNETWORK_SECONDARYIPRANGEENTRY._serialized_start=1086
  _COMPUTESUBNETWORK_SECONDARYIPRANGEENTRY._serialized_end=1141
  _COMPUTESUBNETWORKIAMBINDINGXCONDITION._serialized_start=1143
  _COMPUTESUBNETWORKIAMBINDINGXCONDITION._serialized_end=1238
  _COMPUTESUBNETWORKIAMBINDING._serialized_start=1241
  _COMPUTESUBNETWORKIAMBINDING._serialized_end=1531
  _COMPUTESUBNETWORKIAMMEMBERXCONDITION._serialized_start=1533
  _COMPUTESUBNETWORKIAMMEMBERXCONDITION._serialized_end=1627
  _COMPUTESUBNETWORKIAMMEMBER._serialized_start=1630
  _COMPUTESUBNETWORKIAMMEMBER._serialized_end=1917
  _COMPUTESUBNETWORKIAMPOLICY._serialized_start=1920
  _COMPUTESUBNETWORKIAMPOLICY._serialized_end=2105
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DataLakeSettingsAdmins(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___DataLakeSettingsAdmins = DataLakeSettingsAdmins

@typing_extensions.final
class DataLakeSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADMINS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def admins(self) -> global___DataLakeSettingsAdmins: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        admins: global___DataLakeSettingsAdmins | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["admins", b"admins", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admins", b"admins", "resource_info", b"resource_info"]) -> None: ...

global___DataLakeSettings = DataLakeSettings

@typing_extensions.final
class LakeFormation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LAKE_SETTINGS_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    DATA_LAKE_SETTINGS_DATA_LAKE_PRINCIPAL_FIELD_NUMBER: builtins.int
    @property
    def data_lake_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLakeSettings]: ...
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permissions]: ...
    @property
    def resource(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Resource]: ...
    @property
    def data_lake_settings_data_lake_principal(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataLakeSettingsDataLakePrincipal]: ...
    def __init__(
        self,
        *,
        data_lake_settings: collections.abc.Iterable[global___DataLakeSettings] | None = ...,
        permissions: collections.abc.Iterable[global___Permissions] | None = ...,
        resource: collections.abc.Iterable[global___Resource] | None = ...,
        data_lake_settings_data_lake_principal: collections.abc.Iterable[global___DataLakeSettingsDataLakePrincipal] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_lake_settings", b"data_lake_settings", "data_lake_settings_data_lake_principal", b"data_lake_settings_data_lake_principal", "permissions", b"permissions", "resource", b"resource"]) -> None: ...

global___LakeFormation = LakeFormation

@typing_extensions.final
class PermissionsDataLakePrincipal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_LAKE_PRINCIPAL_IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data_lake_principal_identifier: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_lake_principal_identifier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_lake_principal_identifier", b"data_lake_principal_identifier", "resource_info", b"resource_info"]) -> None: ...

global___PermissionsDataLakePrincipal = PermissionsDataLakePrincipal

@typing_extensions.final
class PermissionsTableWildcard(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___PermissionsTableWildcard = PermissionsTableWildcard

@typing_extensions.final
class PermissionsTableResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    TABLE_WILDCARD_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    database_name: builtins.str
    catalog_id: builtins.str
    @property
    def table_wildcard(self) -> global___PermissionsTableWildcard: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        database_name: builtins.str = ...,
        catalog_id: builtins.str = ...,
        table_wildcard: global___PermissionsTableWildcard | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "table_wildcard", b"table_wildcard"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "database_name", b"database_name", "name", b"name", "resource_info", b"resource_info", "table_wildcard", b"table_wildcard"]) -> None: ...

global___PermissionsTableResource = PermissionsTableResource

@typing_extensions.final
class PermissionsDatabaseResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    catalog_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        catalog_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PermissionsDatabaseResource = PermissionsDatabaseResource

@typing_extensions.final
class PermissionsDataLocationResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_RESOURCE_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_resource: builtins.str
    catalog_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_resource: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "resource_info", b"resource_info", "s3_resource", b"s3_resource"]) -> None: ...

global___PermissionsDataLocationResource = PermissionsDataLocationResource

@typing_extensions.final
class PermissionsColumnWildcard(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXCLUDED_COLUMN_NAMES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def excluded_column_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        excluded_column_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["excluded_column_names", b"excluded_column_names", "resource_info", b"resource_info"]) -> None: ...

global___PermissionsColumnWildcard = PermissionsColumnWildcard

@typing_extensions.final
class PermissionsTableWithColumnsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COLUMN_NAMES_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COLUMN_WILDCARD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def column_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    database_name: builtins.str
    catalog_id: builtins.str
    name: builtins.str
    @property
    def column_wildcard(self) -> global___PermissionsColumnWildcard: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        column_names: collections.abc.Iterable[builtins.str] | None = ...,
        database_name: builtins.str = ...,
        catalog_id: builtins.str = ...,
        name: builtins.str = ...,
        column_wildcard: global___PermissionsColumnWildcard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["column_wildcard", b"column_wildcard", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "column_names", b"column_names", "column_wildcard", b"column_wildcard", "database_name", b"database_name", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PermissionsTableWithColumnsResource = PermissionsTableWithColumnsResource

@typing_extensions.final
class PermissionsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TABLE_RESOURCE_FIELD_NUMBER: builtins.int
    DATABASE_RESOURCE_FIELD_NUMBER: builtins.int
    DATA_LOCATION_RESOURCE_FIELD_NUMBER: builtins.int
    TABLE_WITH_COLUMNS_RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def table_resource(self) -> global___PermissionsTableResource: ...
    @property
    def database_resource(self) -> global___PermissionsDatabaseResource: ...
    @property
    def data_location_resource(self) -> global___PermissionsDataLocationResource: ...
    @property
    def table_with_columns_resource(self) -> global___PermissionsTableWithColumnsResource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        table_resource: global___PermissionsTableResource | None = ...,
        database_resource: global___PermissionsDatabaseResource | None = ...,
        data_location_resource: global___PermissionsDataLocationResource | None = ...,
        table_with_columns_resource: global___PermissionsTableWithColumnsResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_location_resource", b"data_location_resource", "database_resource", b"database_resource", "resource_info", b"resource_info", "table_resource", b"table_resource", "table_with_columns_resource", b"table_with_columns_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_location_resource", b"data_location_resource", "database_resource", b"database_resource", "resource_info", b"resource_info", "table_resource", b"table_resource", "table_with_columns_resource", b"table_with_columns_resource"]) -> None: ...

global___PermissionsResource = PermissionsResource

@typing_extensions.final
class Permissions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_LAKE_PRINCIPAL_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    PERMISSIONS_WITH_GRANT_OPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def data_lake_principal(self) -> global___PermissionsDataLakePrincipal: ...
    @property
    def resource(self) -> global___PermissionsResource: ...
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def permissions_with_grant_option(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_lake_principal: global___PermissionsDataLakePrincipal | None = ...,
        resource: global___PermissionsResource | None = ...,
        permissions: collections.abc.Iterable[builtins.str] | None = ...,
        permissions_with_grant_option: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_lake_principal", b"data_lake_principal", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_lake_principal", b"data_lake_principal", "permissions", b"permissions", "permissions_with_grant_option", b"permissions_with_grant_option", "resource", b"resource", "resource_info", b"resource_info"]) -> None: ...

global___Permissions = Permissions

@typing_extensions.final
class Resource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    USE_SERVICE_LINKED_ROLE_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    use_service_linked_role: builtins.bool
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        use_service_linked_role: builtins.bool = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn", "use_service_linked_role", b"use_service_linked_role"]) -> None: ...

global___Resource = Resource

@typing_extensions.final
class DataLakeSettingsDataLakePrincipal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_LAKE_PRINCIPAL_IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data_lake_principal_identifier: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_lake_principal_identifier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_lake_principal_identifier", b"data_lake_principal_identifier", "resource_info", b"resource_info"]) -> None: ...

global___DataLakeSettingsDataLakePrincipal = DataLakeSettingsDataLakePrincipal



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_elastic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_elastic.proto\x12#oak9.tython.azure.microsoft_elastic\x1a\x13shared/shared.proto\"T\n\x11Microsoft_Elastic\x12?\n\x08monitors\x18\x01 \x03(\x0b\x32-.oak9.tython.azure.microsoft_elastic.Monitors\"\xb7\x01\n\x10MonitorsTagRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12@\n\tlog_rules\x18\x03 \x01(\x0b\x32-.oak9.tython.azure.microsoft_elastic.LogRules\x12\x1a\n\x12provisioning_state\x18\x04 \x01(\t\"\xa8\x01\n\x08LogRules\x12I\n\x0e\x66iltering_tags\x18\x01 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_elastic.FilteringTag\x12\x15\n\rsend_aad_logs\x18\x02 \x01(\x08\x12\x1a\n\x12send_activity_logs\x18\x03 \x01(\x08\x12\x1e\n\x16send_subscription_logs\x18\x04 \x01(\x08\";\n\x0c\x46ilteringTag\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb3\x05\n\x08Monitors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x08identity\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_elastic.IdentityProperties\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12R\n\x12\x65lastic_properties\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_elastic.ElasticProperties\x12\x1f\n\x17liftr_resource_category\x18\x06 \x01(\t\x12\x19\n\x11monitoring_status\x18\x07 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x08 \x01(\t\x12@\n\tuser_info\x18\t \x01(\x0b\x32-.oak9.tython.azure.microsoft_elastic.UserInfo\x12\x0f\n\x07version\x18\n \x01(\t\x12=\n\x03sku\x18\x0b \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_elastic.ResourceSku\x12\x45\n\x04tags\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_elastic.Monitors.TagsEntry\x12Q\n\x12monitors_tag_rules\x18\r \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_elastic.MonitorsTagRules\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1b\n\x0bResourceSku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa6\x01\n\x08UserInfo\x12\x46\n\x0c\x63ompany_info\x18\x01 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_elastic.CompanyInfo\x12\x14\n\x0c\x63ompany_name\x18\x02 \x01(\t\x12\x15\n\remail_address\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\"i\n\x0b\x43ompanyInfo\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x18\n\x10\x65mployees_number\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\"\xc5\x01\n\x11\x45lasticProperties\x12]\n\x18\x65lastic_cloud_deployment\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_elastic.ElasticCloudDeployment\x12Q\n\x12\x65lastic_cloud_user\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_elastic.ElasticCloudUser\" \n\x10\x45lasticCloudUser\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x45lasticCloudDeployment\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n\x12IdentityProperties\x12\x0c\n\x04type\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_elastic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MONITORS_TAGSENTRY._options = None
  _MONITORS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_ELASTIC._serialized_start=97
  _MICROSOFT_ELASTIC._serialized_end=181
  _MONITORSTAGRULES._serialized_start=184
  _MONITORSTAGRULES._serialized_end=367
  _LOGRULES._serialized_start=370
  _LOGRULES._serialized_end=538
  _FILTERINGTAG._serialized_start=540
  _FILTERINGTAG._serialized_end=599
  _MONITORS._serialized_start=602
  _MONITORS._serialized_end=1293
  _MONITORS_TAGSENTRY._serialized_start=1250
  _MONITORS_TAGSENTRY._serialized_end=1293
  _RESOURCESKU._serialized_start=1295
  _RESOURCESKU._serialized_end=1322
  _USERINFO._serialized_start=1325
  _USERINFO._serialized_end=1491
  _COMPANYINFO._serialized_start=1493
  _COMPANYINFO._serialized_end=1598
  _ELASTICPROPERTIES._serialized_start=1601
  _ELASTICPROPERTIES._serialized_end=1798
  _ELASTICCLOUDUSER._serialized_start=1800
  _ELASTICCLOUDUSER._serialized_end=1832
  _ELASTICCLOUDDEPLOYMENT._serialized_start=1834
  _ELASTICCLOUDDEPLOYMENT._serialized_end=1872
  _IDENTITYPROPERTIES._serialized_start=1874
  _IDENTITYPROPERTIES._serialized_end=1908
# @@protoc_insertion_point(module_scope)
